==> user-repository-sequelize-0.0.1.tgz: package/src/userRepository.ts <==
import { createHash, IUserRepository } from '@goodrequest/passport-jwt-wrapper'
import { col, fn, Op, where, WhereOptions, Transaction } from 'sequelize'
import { createSlug } from './utils/helpers'
import { UserModel } from './models/user'

// eslint-disable-next-line import/prefer-default-export
export class UserRepository<M extends typeof UserModel> implements IUserRepository<number> {
	user: M

	constructor(user: M) {
		this.user = user
	}

	async getUsers(limit: number, page: number, sort: string, search?: string): Promise<UserModel[]> {
		const userConditions: { [Op.and]: WhereOptions[] } = {
			[Op.and]: []
		}

		if (search) {
			const slugValue = createSlug(search)
			const searchConditions = slugValue.split('-').map((slug: string) =>
				where(fn('CONCAT_WS', '-', col('user.emailSlug'), col('user.nameSlug'), col('user.surnameSlug'), col('user.phoneSlug')), {
					[Op.iLike]: `%${slug}%`
				})
			)
			userConditions[Op.and].push(...searchConditions)
		}

		const offset = page * limit - limit

		const users = await this.user.findAll({
			attributes: ['id', 'name', 'surname', 'email', 'permission', 'confirmedAt'],
			where: userConditions,
			offset,
			limit,
			order: [['id', 'ASC']]
		})

		return users
	}

	async getUserByEmail(email: string): Promise<UserModel | undefined> {
		const user = await this.user.findOne({
			attributes: ['id', 'name', 'surname', 'email', 'permission', 'confirmedAt', 'hash'],
			where: {
				email
			}
		})

		return user ?? undefined
	}

	async getUserById(id: number): Promise<UserModel | undefined> {
		const user = await this.user.findByPk(id, {
			attributes: ['id', 'name', 'surname', 'email', 'permission', 'confirmedAt']
		})

		return user ?? undefined
	}

	async updateUserPassword(id: number, newPassword: string, transaction?: Transaction): Promise<void> {
		const user = await this.user.findByPk(id)

		if (!user) {
			throw new Error('error:User was not found')
		}

		const hash = await createHash(newPassword)

		try {
			await user.update(
				{
					hash,
					updatedBy: id
				},
				{
					transaction
				}
			)

			if (transaction) {
				await transaction.commit()
			}
		} catch (e) {
			if (transaction) {
				await transaction.rollback()
			}

			throw e
		}
	}

	/**
	 * return user only if he has no password set -- is not registered
	 * @param userID
	 */
	async getNewUserById(userID: number): Promise<UserModel | undefined> {
		const user = await this.user.findOne({
			where: {
				id: userID,
				hash: { [Op.is]: null }
			}
		})

		return user ?? undefined
	}
}

==> user-repository-sequelize-0.1.1.tgz: package/src/userRepository.ts <==
import { createHash, ID, IUserRepository } from '@goodrequest/passport-jwt-wrapper'
import { col, fn, Op, where, WhereOptions, Transaction } from 'sequelize'
import { createSlug } from './utils/helpers'
import { BaseUserModel } from './models/baseUser'

// eslint-disable-next-line import/prefer-default-export
export class UserRepository<IDType extends ID, M extends typeof BaseUserModel<IDType>> implements IUserRepository<IDType> {
	user: M

	constructor(user: M) {
		this.user = user
	}

	async getUsers(limit: number, page: number, sort: string, search?: string): Promise<BaseUserModel<IDType>[]> {
		const userConditions: { [Op.and]: WhereOptions[] } = {
			[Op.and]: []
		}

		if (search) {
			const slugValue = createSlug(search)
			const searchConditions = slugValue.split('-').map((slug: string) =>
				where(fn('CONCAT_WS', '-', col('user.emailSlug'), col('user.nameSlug'), col('user.surnameSlug'), col('user.phoneSlug')), {
					[Op.iLike]: `%${slug}%`
				})
			)
			userConditions[Op.and].push(...searchConditions)
		}

		const offset = page * limit - limit

		const users = await this.user.findAll({
			attributes: ['id', 'name', 'surname', 'email', 'permission', 'confirmedAt'],
			where: userConditions,
			offset,
			limit,
			order: [['id', 'ASC']]
		})

		return users
	}

	async getUserByEmail(email: string): Promise<BaseUserModel<IDType> | undefined> {
		const user = await this.user.findOne({
			attributes: ['id', 'name', 'surname', 'email', 'permission', 'confirmedAt', 'hash'],
			where: {
				email: {
					[Op.iLike]: email
				},
				confirmedAt: {
					[Op.not]: null
				},
				hash: {
					[Op.not]: null
				}
			}
		})

		return user ?? undefined
	}

	async getUserById(id: IDType): Promise<BaseUserModel<IDType> | undefined> {
		const user = await this.user.findByPk(id, {
			attributes: ['id', 'name', 'surname', 'email', 'permission', 'confirmedAt']
		})

		return user ?? undefined
	}

	async updateUserPassword(id: IDType, newPassword: string, transaction?: Transaction): Promise<BaseUserModel<IDType>> {
		const user = await this.user.findByPk(id, {
			attributes: ['id', 'hash']
		})

		if (!user) {
			throw new Error('error:User was not found')
		}

		const hash = await createHash(newPassword)

		try {
			const updatedUsers = await user.update(
				{
					hash,
					updatedBy: id
				},
				{
					transaction
				}
			)

			if (transaction) {
				await transaction.commit()
			}

			return updatedUsers
		} catch (e) {
			if (transaction) {
				await transaction.rollback()
			}

			throw e
		}
	}

	/**
	 * return user only if he has no password set -- is not registered
	 * @param userID
	 */
	async getNewUserById(userID: IDType): Promise<BaseUserModel<IDType> | undefined> {
		const user = await this.user.findOne({
			where: {
				id: userID,
				hash: { [Op.is]: null }
			}
		})

		return user ?? undefined
	}
}
